@@ -1,3 +1,3 @@
 from join_eos_exif.OrthoRenamer import GeographicOrthoRenamer, UTMOrthoRenamer
 
-__all__ = ("GeographicOrthoRenamer", "UTMOrthoRenamer",)
+__all__ = ("UTMOrthoRenamer", "GeographicOrthoRenamer")
